/****************************************************************************
** Meta object code from reading C++ file 'board_widget.h'
**
** Created: Sat Feb 21 18:01:58 2009
**      by: The Qt Meta Object Compiler version 59 (Qt 4.4.3)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "board_widget.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'board_widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 59
#error "This file was generated using the moc from 4.4.3. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_BoardWidget[] = {

 // content:
       1,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   10, // methods
       0,    0, // properties
       0,    0, // enums/sets

 // slots: signature, parameters, type, tag, flags
      19,   13,   12,   12, 0x0a,
      46,   12,   12,   12, 0x0a,
      63,   56,   12,   12, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_BoardWidget[] = {
    "BoardWidget\0\0iGame\0setGame(const PublicGame*)\0"
    "refresh()\0iCoord\0updateArrow(Coord)\0"
};

const QMetaObject BoardWidget::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_BoardWidget,
      qt_meta_data_BoardWidget, 0 }
};

const QMetaObject *BoardWidget::metaObject() const
{
    return &staticMetaObject;
}

void *BoardWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_BoardWidget))
        return static_cast<void*>(const_cast< BoardWidget*>(this));
    return QFrame::qt_metacast(_clname);
}

int BoardWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: setGame((*reinterpret_cast< const PublicGame*(*)>(_a[1]))); break;
        case 1: refresh(); break;
        case 2: updateArrow((*reinterpret_cast< const Coord(*)>(_a[1]))); break;
        }
        _id -= 3;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
